@@ -56,7 +56,7 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
         if self.admin_path and self.path.startswith(self.admin_path):
             self.admin_handler()
             return
-        
+
         req = self
         content_length = int(req.headers.get('Content-Length', 0))
         req_body = self.rfile.read(content_length) if content_length else None
@@ -79,7 +79,7 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
 
         u = urllib.parse.urlsplit(req.path)
         scheme, netloc, path = u.scheme, u.netloc, (u.path + '?' + u.query if u.query else u.path)
-        assert scheme in ('http', 'https')
+        assert scheme in ('http', 'https', 'about')
         if netloc:
             req.headers['Host'] = netloc
         setattr(req, 'headers', self._filter_headers(req.headers))
@@ -99,9 +99,8 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
 
             res_body = res.read()
         except Exception:
-            if origin in self.tls.conns:
-                del self.tls.conns[origin]
-            self.send_error(502)
+            self.log_error('Error making request')
+            self.close_connection = True
             return
 
         res_body_modified = self.response_handler(req, req_body, res, res_body)
@@ -201,7 +200,7 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
         return headers
 
     def _keepalive(self):
-        return self.server.options.get('connection_keep_alive', True) \
+        return self.server.options.get('connection_keep_alive', False) \
                and self.headers.get('Connection', '').lower() != 'close'
 
     def _handle_websocket(self, server_sock):
@@ -287,13 +286,6 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
         """
         pass
 
-    def log_error(self, format_, *args):
-        # suppress "Request timed out: timeout('timed out',)"
-        if isinstance(args[0], socket.timeout):
-            return
-
-        self.log_message(format_, *args)
-
 
 class ProxyAwareHTTPConnection(HTTPConnection):
     """A specialised HTTPConnection that will transparently connect to a
@@ -390,6 +382,8 @@ def _create_auth_header(proxy_username, proxy_password, custom_proxy_authorizati
     headers = {}
 
     if proxy_username and proxy_password and not custom_proxy_authorization:
+        proxy_username = urllib.parse.unquote(proxy_username)
+        proxy_password = urllib.parse.unquote(proxy_password)
         auth = '{}:{}'.format(proxy_username, proxy_password)
         headers['Proxy-Authorization'] = 'Basic {}'.format(base64.b64encode(auth.encode('utf-8')).decode('utf-8'))
     elif custom_proxy_authorization:
